attendance_ruler library

A package that gives us a attendance ruler a custom widget. This widget is used to show the attendance time on the ruler with easy customization.

Classes

AttendanceDataModel
Used to define the data model for the AttendanceRuler
AttendanceRuler
Root widget to paint the actual attendance ruler on the canvas
AttendanceRulerDecoration
Used to decorate the AttendanceRuler Widget
HoursOfAttendance
Used to define the calculated hours from the AttendanceData
InOutTime
Used to define In and Out Time in the Day

Enums

RulerTimeFormat
Defines the Hours format for the Ruler Time Such as 24 hours or 12 hours
RulerTimeRoundedCornerStyle
Defines the rounded corner style for the Time Such as all rounded, first and last only and nothing

Functions

durationToTimeOfDay(Duration duration) TimeOfDay
Used to get the TimeOfDay from the Duration
getCalculatedHoursFromAttendance(AttendanceDataModel attendanceDataModel, {RulerTimeFormat rulerTimeFormat = RulerTimeFormat.twentyFourHours}) HoursOfAttendance
Used to get the calculated hours from the attendance Returns HoursOfAttendance with effective, break and gross Hours